#
# spec file for package xf86-video-siliconmotion
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xf86-video-siliconmotion
Version:        1.7.10
Release:        1.1
Summary:        Silicon Motion video driver for the Xorg X server
License:        MIT
Group:          System/X11/Servers/XF86_4
URL:            http://xorg.freedesktop.org/
Source0:        http://xorg.freedesktop.org/releases/individual/driver/%{name}-%{version}.tar.xz
Source2:        %{name}.keyring
Patch0:         u_siliconmotion_fix_segfault_on_xorg_server_1.19.patch
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(fontsproto)
BuildRequires:  pkgconfig(pciaccess) >= 0.8.0
BuildRequires:  pkgconfig(randrproto)
BuildRequires:  pkgconfig(renderproto)
BuildRequires:  pkgconfig(videoproto)
BuildRequires:  pkgconfig(xextproto)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xorg-server) >= 1.0.99.901
BuildRequires:  pkgconfig(xproto)
Supplements:    modalias(xorg-x11-server:pci:v0000126FD*sv*sd*bc03sc*i*)
# This was part of the xorg-x11-driver-video package up to version 7.6
Conflicts:      xorg-x11-driver-video <= 7.6
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExcludeArch:    s390 s390x aarch64 %arm
%x11_abi_videodrv_req

%description
siliconmotion is an Xorg driver for Silicon Motion video cards.

The driver is fully accelerated, and provides support for the following
framebuffer depths: 8, 16, and 24. All visual types are supported for
depth 8, and TrueColor visuals are supported for the other depths.

%prep
%setup -q
%patch0 -p1

%build
%configure
make %{?_smp_mflags}

%install
%make_install
find %{buildroot}%{_libdir} -name '*.la' -type f -delete -print

%files
%defattr(-,root,root)
%doc ChangeLog README.md
%license COPYING
%dir %{_libdir}/xorg/modules/drivers
%{_libdir}/xorg/modules/drivers/siliconmotion_drv.so
%{_datadir}/man/man4/siliconmotion.4%{?ext_man}

%changelog
* Thu Sep 28 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.7.10
  * Update README for gitlab migration
  * Update configure.ac bug URL for gitlab migration
  * Build xz tarballs instead of bzip2
  * Fix spelling/wording issues
  * gitlab CI: add a basic build test
  * gitlab CI: stop requiring Signed-off-by in commits
  * constify some char * declarations
  * Quiet -Wempty-body warning
  * Replace malloc()+snprintf() with Xasprintf()
  * Replace malloc()+memset() with calloc()
  * Remove "All rights reserved" from Oracle copyright notices
  * gitlab CI: ensure libtool is installed in build container
  * autogen.sh: Implement GNOME Build API
  * autogen.sh: use quoted string variables
  * autogen: add default patch prefix
  * configure: Drop AM_MAINTAINER_MODE
  * autogen.sh: use exec instead of waiting for configure to finish
* Mon Jan 20 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add %%arm to ExcludeArch, build fails since glibc dropped outb/inb
  support
* Thu Jul 20 2017 stefan.bruens@rwth-aachen.de
- Add aarch64 to ExcludeArch, build fails due to unsupported outb
* Tue Apr 11 2017 lbsousajr@gmail.com
- u_siliconmotion_fix_segfault_on_xorg_server_1.19.patch
  * fixes segfault at ScreenInit on Xorg server 1.19 (boo#1033528)
* Thu Jan 19 2017 sndirsch@suse.com
-  Update to version 1.7.9
  * Adapt Block/WakeupHandler signature for ABI 23
  * Check for drawables before compositing
  * Use X11/Xarch.h for endian detection.
* Wed Nov 30 2016 sndirsch@suse.com
- U_Adapt-Block-WakeupHandler-signature-for-ABI-23.patch
  * Adapt Block/WakeupHandler signature for ABI 23
* Sun Sep 27 2015 mpluskal@suse.com
- Add gpg signature
* Sun May 10 2015 zaitor@opensuse.org
- Update to version 1.7.8:
  + Remove miInitializeBackingStore().
  + Use own thunk function instead of vgaHW*Weak.
  + Fix build against xserver 1.17.
  + Fix a typo.
  + Remove dependency on xf86PciInfo.h.
  + Fix shadow compiler warning.
  + Fix BlockHandler declaration.
  + Fix SwitchMode and AdjustFrame hooks.
  + Fix a couple const-ness warnings.
- Drop U_Fix-build-against-xserver-1.17.patch and
  U_Remove-miInitializeBackingStore.patch: fixed upstream.
* Fri Feb  6 2015 sndirsch@suse.com
- U_Fix-build-against-xserver-1.17.patch
  * fixes build against xorg-server 1.17
* Wed Aug  7 2013 ro@suse.de
- add ExcludeArch for s390 and s390x
* Thu Mar 21 2013 sndirsch@suse.com
- Remove miInitializeBackingStore()
* Wed Mar 20 2013 sndirsch@suse.com
- introduce hardware supplements conditional on xorg-x11-server
  package (bnc#810333)
* Sun Sep  2 2012 zaitor@opensuse.org
- Update to version 1.7.7:
  + Convert to new X server screen conversion apis.
  + Port to compat-api for new server.
  + Fix build against XAA-less server.
* Thu Apr 19 2012 dimstar@opensuse.org
- Update to version 1.7.6:
  + Don't check for randrproto or renderproto
  + Fix for new vgaHW ABI
  + Make failure to XAA non-fatal
  + Check ABI major not encoded ABI
  + Adapt to missing PIOOffset in videoabi 12
- Use %%x11_abi_videodrv_req instead of static ABI Requires.
* Wed Apr 18 2012 vuntz@opensuse.org
- Split xf86-video-siliconmotion from xorg-x11-driver-video.
  Initial version: 1.7.5.
